@@ -1,31 +1,30 @@
-"plotDive" <- function(time, depth, vel=NULL, xlim=NULL, phaseCol=NULL)
+"plotDive" <- function(time, depth, speed=NULL, xlim=NULL, phaseCol=NULL)
 {
-    ## Value: Plot of time, depth, velocity, mostly for ZOC, returns a
-    ## list with coordinates for each zoc'ed time window.
+    ## Value: Plot of time, depth, speed, mostly for ZOC, returns
+    ## (invisibly) a list with coordinates for each zoc'ed time window.
     ## --------------------------------------------------------------------
-    ## Arguments: time=POSIXct; depth and vel=numeric vectors of depth and
-    ## velocity
+    ## Arguments: time=POSIXct; depth and speed=numeric vectors of depth
+    ## and speed
     ## --------------------------------------------------------------------
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
     require(tcltk) || stop("tcltk support is absent")
     rx <- range(as.numeric(time))       # max and min of dates
+    diffrx <- diff(rx)
     xlim <- x10 <- if(is.null(xlim)) {  # define xlim if not there already
-        rx + (diff(rx) * 0.01)          # add 1% to each side
-    } else {
-        as.numeric(xlim)
-    }
-    xlmid <- xm0 <- mean(xlim)            # two vars with date range midpoint
+        rx + (diffrx * 0.01)            # add 1% to each side
+    } else as.numeric(xlim)
+    xlmid <- xm0 <- mean(xlim)         # two vars with date range midpoint
     xr0 <- diff(xlim)                     # range of xlim
     xZoom <- tclVar(100)                  # initialize zoom factor
     xlmid <- tclVar(xlmid)                # initialize date range midpoint
-    xZ <- as.numeric(tclvalue(xZoom))     # these 2 are to be dynamically changed
+    xZ <- as.numeric(tclvalue(xZoom)) # these 2 are to be dynamically changed
     xM <- as.numeric(tclvalue(xlmid))
     ylim <- rev(range(depth, na.rm=TRUE))
     yMax <- tclVar(ylim[1])
     yTop <- as.numeric(tclvalue(yMax))
     replot <- function(...) {
-        if(is.null(vel)) {
+        if(is.null(speed)) {
             par(lab=c(10, 10, 7), las=1, xaxs="i", cex.axis=0.7,
                 cex.lab=1.3, bty="n", mar=c(4, 4, 1, 1) + 0.1)
         } else {
@@ -49,11 +48,14 @@
              xlab="date (mm-dd hh:mm:ss)",
              ylab="depth (m)", xaxt="n", yaxt="n")
         usr <- par("usr")
-        rect(night, usr[3], morn, usr[4], col="black")
+        xleft <- pmax(night, usr[1])
+        xright <- pmin(morn, usr[2])
+        rect(xleft, usr[3], xright, usr[4], col="black")
         axis.POSIXct(side=1, time, at=xticks, lwd=2, format="%m-%d %H:%M:%S")
         axis(side=2, lwd=2)
         lines(time, depth, col="blue")
-        if (!is.null(phaseCol)) {
+        if (!is.null(phaseCol) & nlevels(phaseCol[drop=TRUE]) < 11) {
+            phaseCol <- phaseCol[drop=TRUE]
             colors <- rainbow(nlevels(phaseCol))
             points(time, depth, col=colors[phaseCol], pch=19, cex=0.4)
             legend("bottomright", legend=levels(phaseCol), col=colors,
@@ -61,15 +63,15 @@
         }
         legend("bottomleft", legend=c("18:00 - 06:00"), fill=c("black"),
                cex=0.7, bg="white", y.intersp=1.2)
-        if(!is.null(vel)) {
+        if(!is.null(speed)) {
             par(mar=c(-0.1, 4, 1, 1) + 0.1)
-            ylim <- range(vel, na.rm=TRUE)
-            plot(vel ~ time, type="n", xaxt="n", ylim=ylim,
-                 xlab="", xlim=xlim, bty="n", ylab="velocity (m/s)")
-            rect(night, usr[3], morn, usr[4], col="black")
-            lines(time, vel, col="green")
+            ylim <- range(speed, na.rm=TRUE)
+            plot(speed ~ time, type="n", xaxt="n", ylim=ylim,
+                 xlab="", xlim=xlim, bty="n", ylab="speed (m/s)")
+            rect(xleft, usr[3], xright, usr[4], col="black")
+            lines(time, speed, col="green")
             if (!is.null(phaseCol)) {           # we already have 'colors'
-                points(time, vel, col=colors[phaseCol], pch=19, cex=0.4)
+                points(time, speed, col=colors[phaseCol], pch=19, cex=0.4)
             }
             axis(side=2, lwd=2)
         }
@@ -95,9 +97,10 @@
 
     x.frame <- tkframe(base.frame)
     xr.frame <- tkframe(x.frame, relief="groove", borderwidth=5)
-    xmid.frame <- tkframe(x.frame, relief="groove", borderwidth=5)
     dep.frame <- tkframe(x.frame, relief="groove", borderwidth=5)
-    tkpack(xmid.frame, xr.frame, dep.frame, side="left", anchor="s")
+    tkpack(xr.frame, dep.frame, side="left", anchor="s")
+
+    xmid.frame <- tkframe(base.frame, relief="groove", pady=5)
 
     but.frame <- tkframe(base)
     zoc.pts <- tkbutton(but.frame, text="Zero-Offset Correct a Range",
@@ -106,12 +109,15 @@
                       command=function() tkdestroy(base))
     tkpack(zoc.pts, q.but, side="left", padx=20)
 
-    tkpack(base.frame, x.frame, but.frame)
+    tkpack(base.frame, x.frame, xmid.frame, but.frame)
 
     ## Zoom
+    diffx <- diff(as.numeric(time))
+    diffxOK <- min(diffx[diffx > 0]) * 40 # zoom up to 40 observations
+    maxZoom <- (diffrx / diffxOK) * 100 # maximum zoom depends on time range
     tkpack(tklabel(xr.frame, text="Date Zoom (%)"))
     tkpack(tkscale(xr.frame, command=replot.maybe, from=100,
-                   to=30000, showvalue=TRUE, variable=xZoom,
+                   to=maxZoom, showvalue=TRUE, variable=xZoom,
                    length=200, orient="horiz"))
     ## Pan
     tkpack(tklabel(xmid.frame, text="Pan through Date"))
